pub fn paint_ground(
ctx: &CanvasRenderingContext2d,
viewport: Rect,
vantage: Vantage,
ground: Ground,
)Expand description
Fill viewport and rule the grid vantage shows over it.
pub fn paint_ground(
ctx: &CanvasRenderingContext2d,
viewport: Rect,
vantage: Vantage,
ground: Ground,
)Fill viewport and rule the grid vantage shows over it.