shift_is_a_modifier_of

Function shift_is_a_modifier_of 

fn shift_is_a_modifier_of(pressed: &str) -> bool
Shift is a modifier of a letter, which arrives as the same letter either way, and spent on anything else: a shifted = arrives as +, its own key.