pointer

Function pointer 

pub fn pointer(
    event: &PointerEvent,
    phase: Phase,
    origin: Pos2,
) -> PointerSample
One pointer event as the listener that caught it names its phase. origin is the canvas’s top-left in client coordinates, so the sample is in the canvas’s own CSS pixels.