pub enum Repaint {
Settled,
Owed,
}Expand description
Whether the frame just drawn is the whole diagram, or whether something it named was not ready and another frame is owed once it is.
Variants
Implementations